Learn R Programming

gammi (version 0.2)

summary.gammi: Summary Method for gammi Fits

Description

Obtain summary statistics from a fit generalized additive mixed model (gammi) object.

Usage

# S3 method for gammi
summary(object, ...)

Value

An object of class "summary.gammi", which is a list with components:

call

the model call, i.e., object$call

term.labels

the model term labels (character vector)

family

the exponential family object

logLik

log-likelihood for the solution

aic

AIC for the solution

deviance

the model deviance (numeric)

deviance.resid

the deviance residuals

r.squared

the model R-squared (numeric); see Note

df

the total degrees of freedom = object$edf + object$df.random

significance

the signififance testing information (matrix)

importance

the variable importance information (numeric)

vif

the variance inflation factors (numeric)

Arguments

object

Object of class "gammi"

...

Additional arguments (currently ignored)

Author

Nathaniel E. Helwig <helwig@umn.edu>

Details

Produces significance testing and model diagnostic information. The significance tests use the Bayesian interpretation of a smoothing spline. The variable importance indices sum to 100 but can be negative for some terms. The variance inflation factors should ideally be 1 for all terms; values greater than 5 or 10 can indicate noteworthy multicollinearity.

References

Helwig, N. E. (2024). Precise tensor product smoothing via spectral splines. Stats, 7(1), 34-53, tools:::Rd_expr_doi("10.3390/stats7010003")

See Also

gammi for fitting generalized additive mixed models

plot.gammi for plotting effects from gammi objects

predict.gammi for predicting from gammi objects

Examples

Run this code
# load 'gammi' package
library(gammi)

# load data
data(exam)

# header of data
head(exam)

# fit model
mod <- gammi(Exam.score ~ VRQ.score, data = exam,
             random = ~ (1 | Primary.school) + (1 | Secondary.school))
       
# summarize results
summary(mod)

# refit model with Secondary.school as penalized nominal effect
mod <- gammi(Exam.score ~ Secondary.school + VRQ.score, data = exam,
             random = ~ (1 | Primary.school))
             
# summarize results
summary(mod)

Run the code above in your browser using DataLab